# Deelink - Конвертер Deezer-ссылок

Утилита для преобразования коротких ссылок Deezer (dzr.page.link) в чистые URL треков.

## Установка

```bash
pip install deelink


Использование
После установки запустите утилиту командой:

deelink


Затем вставьте короткую ссылку Deezer и нажмите Enter. Программа покажет:

1. Оригинальную ссылку

2. URL после редиректа

3. Чистую ссылку на трек

Для выхода введите exit или нажмите Ctrl+C.

Контакты автора

Email: shizofrin@gmail.com

Twitter (X): @Lanaev0li

elegram: @akrim



Лицензия
MIT License © 2025 Avinion